==> aws-sdk-cpp-1.11.686-1-x86_64.pkg.tar.zst: usr/include/aws/qconnect/model/AssistantAssociationInputData.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/qconnect/QConnect_EXPORTS.h>

#include <utility>

namespace Aws {
namespace Utils {
namespace Json {
class JsonValue;
class JsonView;
}  // namespace Json
}  // namespace Utils
namespace QConnect {
namespace Model {

/**
 * <p>The data that is input into Amazon Q in Connect as a result of the assistant
 * association.</p><p><h3>See Also:</h3>   <a
 * href="http://docs.aws.amazon.com/goto/WebAPI/qconnect-2020-10-19/AssistantAssociationInputData">AWS
 * API Reference</a></p>
 */
class AssistantAssociationInputData {
 public:
  AWS_QCONNECT_API AssistantAssociationInputData() = default;
  AWS_QCONNECT_API AssistantAssociationInputData(Aws::Utils::Json::JsonView jsonValue);
  AWS_QCONNECT_API AssistantAssociationInputData& operator=(Aws::Utils::Json::JsonView jsonValue);
  AWS_QCONNECT_API Aws::Utils::Json::JsonValue Jsonize() const;

  ///@{
  /**
   * <p>The identifier of the knowledge base. This should not be a QUICK_RESPONSES
   * type knowledge base.</p>
   */
  inline const Aws::String& GetKnowledgeBaseId() const { return m_knowledgeBaseId; }
  inline bool KnowledgeBaseIdHasBeenSet() const { return m_knowledgeBaseIdHasBeenSet; }
  template <typename KnowledgeBaseIdT = Aws::String>
  void SetKnowledgeBaseId(KnowledgeBaseIdT&& value) {
    m_knowledgeBaseIdHasBeenSet = true;
    m_knowledgeBaseId = std::forward<KnowledgeBaseIdT>(value);
  }
  template <typename KnowledgeBaseIdT = Aws::String>
  AssistantAssociationInputData& WithKnowledgeBaseId(KnowledgeBaseIdT&& value) {
    SetKnowledgeBaseId(std::forward<KnowledgeBaseIdT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_knowledgeBaseId;
  bool m_knowledgeBaseIdHasBeenSet = false;
};

}  // namespace Model
}  // namespace QConnect
}  // namespace Aws

==> aws-sdk-cpp-1.11.705-1-x86_64.pkg.tar.zst: usr/include/aws/qconnect/model/AssistantAssociationInputData.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/qconnect/QConnect_EXPORTS.h>
#include <aws/qconnect/model/ExternalBedrockKnowledgeBaseConfig.h>

#include <utility>

namespace Aws {
namespace Utils {
namespace Json {
class JsonValue;
class JsonView;
}  // namespace Json
}  // namespace Utils
namespace QConnect {
namespace Model {

/**
 * <p>The data that is input into Amazon Q in Connect as a result of the assistant
 * association.</p><p><h3>See Also:</h3>   <a
 * href="http://docs.aws.amazon.com/goto/WebAPI/qconnect-2020-10-19/AssistantAssociationInputData">AWS
 * API Reference</a></p>
 */
class AssistantAssociationInputData {
 public:
  AWS_QCONNECT_API AssistantAssociationInputData() = default;
  AWS_QCONNECT_API AssistantAssociationInputData(Aws::Utils::Json::JsonView jsonValue);
  AWS_QCONNECT_API AssistantAssociationInputData& operator=(Aws::Utils::Json::JsonView jsonValue);
  AWS_QCONNECT_API Aws::Utils::Json::JsonValue Jsonize() const;

  ///@{
  /**
   * <p>The identifier of the knowledge base. This should not be a QUICK_RESPONSES
   * type knowledge base.</p>
   */
  inline const Aws::String& GetKnowledgeBaseId() const { return m_knowledgeBaseId; }
  inline bool KnowledgeBaseIdHasBeenSet() const { return m_knowledgeBaseIdHasBeenSet; }
  template <typename KnowledgeBaseIdT = Aws::String>
  void SetKnowledgeBaseId(KnowledgeBaseIdT&& value) {
    m_knowledgeBaseIdHasBeenSet = true;
    m_knowledgeBaseId = std::forward<KnowledgeBaseIdT>(value);
  }
  template <typename KnowledgeBaseIdT = Aws::String>
  AssistantAssociationInputData& WithKnowledgeBaseId(KnowledgeBaseIdT&& value) {
    SetKnowledgeBaseId(std::forward<KnowledgeBaseIdT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The configuration for an external Bedrock knowledge base association.</p>
   */
  inline const ExternalBedrockKnowledgeBaseConfig& GetExternalBedrockKnowledgeBaseConfig() const {
    return m_externalBedrockKnowledgeBaseConfig;
  }
  inline bool ExternalBedrockKnowledgeBaseConfigHasBeenSet() const { return m_externalBedrockKnowledgeBaseConfigHasBeenSet; }
  template <typename ExternalBedrockKnowledgeBaseConfigT = ExternalBedrockKnowledgeBaseConfig>
  void SetExternalBedrockKnowledgeBaseConfig(ExternalBedrockKnowledgeBaseConfigT&& value) {
    m_externalBedrockKnowledgeBaseConfigHasBeenSet = true;
    m_externalBedrockKnowledgeBaseConfig = std::forward<ExternalBedrockKnowledgeBaseConfigT>(value);
  }
  template <typename ExternalBedrockKnowledgeBaseConfigT = ExternalBedrockKnowledgeBaseConfig>
  AssistantAssociationInputData& WithExternalBedrockKnowledgeBaseConfig(ExternalBedrockKnowledgeBaseConfigT&& value) {
    SetExternalBedrockKnowledgeBaseConfig(std::forward<ExternalBedrockKnowledgeBaseConfigT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_knowledgeBaseId;
  bool m_knowledgeBaseIdHasBeenSet = false;

  ExternalBedrockKnowledgeBaseConfig m_externalBedrockKnowledgeBaseConfig;
  bool m_externalBedrockKnowledgeBaseConfigHasBeenSet = false;
};

}  // namespace Model
}  // namespace QConnect
}  // namespace Aws
